@@ -5,5 +5,5 @@ from .models import RefreshToken
 
 @admin.register(RefreshToken)
 class RefreshTokenAdmin(admin.ModelAdmin):
-    list_display = ['user', 'token']
-    readonly_fields = ['user', 'token', 'issued']
+    list_display = ['user', 'ip', 'token']
+    readonly_fields = ['user', 'token', 'issued', 'ip', 'userAgent']
